==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/pavement/dialogs_nl.lua <==

dialogId("dir-m-rada0", "font_small", "Stuff yourself with your advice.")
dialogStr("Hou je advies voor je!")


dialogId("dir-m-rada1", "font_small", "We know that very well.")
dialogStr("Dat weten wij ook wel!")


dialogId("dir-m-rada2", "font_small", "Get lost.")
dialogStr("Rot op!")


dialogId("dir-m-rada3", "font_small", "My patience is running out.")
dialogStr("Mijn geduld is op.")


dialogId("dir-m-rada4", "font_small", "Arrgh... I`ll smash it to pieces.")
dialogStr("Arrgh... Ik ga dat ding stuk slaan!")


dialogId("dir-v-rada0", "font_big", "Ignore it, let it talk.")
dialogStr("Negeer hem. Laat hem maar praten.")


dialogId("dir-v-rada1", "font_big", "Let us think.")
dialogStr("Eens denken...")


dialogId("dir-v-rada2", "font_big", "This was some advice, again.")
dialogStr("Dat was alweer advies.")


dialogId("dir-v-rada3", "font_big", "It's a shame I have no ears. I could plug them.")
dialogStr("Jammer dat we geen oren hebben. We zouden er iets in kunnen stoppen.")


dialogId("dir-v-rada4", "font_big", "I am fed up to my gills with its nonsense.")
dialogStr("Ik ben die onzin zo ongeloofelijk zat!")


dialogId("dir-hs-uvod0", "font_statue", "It would be easiest if you")
dialogStr("Het zou het handigst zijn als jullie")


dialogId("dir-hs-uvod1", "font_statue", "You would be better off if you")
dialogStr("Je zou er een stuk beter voor staan als jullie")


dialogId("dir-hs-uvod2", "font_statue", "It would help you if you")
dialogStr("Het zou helpen als jullie")


dialogId("dir-hs-uvod3", "font_statue", "I have an idea. What if you")
dialogStr("Ik heb een idee. Het zou mooi zijn als jullie")


dialogId("dir-hs-uvod4", "font_statue", "Sorry to interrupt, but what if you")
dialogStr("Pardon dat ik onderbreek. Het zou mooi zijn als jullie")


dialogId("dir-hs-konec0", "font_statue", "demolish some wall.")
dialogStr("een paar muren omver zouden duwen.")


dialogId("dir-hs-konec1", "font_statue", "break off a few stones from the wall and plug the holes with them.")
dialogStr("een paar stenen van die muur daar af zouden breken en daar de kuilen mee zouden opvullen.")


dialogId("dir-hs-konec2", "font_statue", "plug those holes with something so that that hooked steel wouldn`t get stuck there.")
dialogStr("deze gaten zouden opvullen met iets, zodat dat hoekige stuk staal niet vast komt te zitten.")


dialogId("dir-hs-konec3", "font_statue", "smash that pillar by the exit.")
dialogStr("de pilaar bij de uitgang stuk zouden maken.")


dialogId("dir-hs-konec4", "font_statue", "saw off some of that hooked steel.")
dialogStr("een stuk van dat hoekige stalen ding af zouden zagen.")


dialogId("dir-hs-konec5", "font_statue", "rearrange the objects so that you can swim out.")
dialogStr("de objecten zo zouden verplaatsen dat jullie hieruit kunnen zwemmen.")


dialogId("dir-hs-konec6", "font_statue", "solve it somehow and get to the next level.")
dialogStr("het de eenofandere manier zouden oplossen en het volgende veld zouden bereiken.")


dialogId("dir-hs-konec7", "font_statue", "start to think about it really hard.")
dialogStr("er heel erg hard over na zouden denken.")


dialogId("dir-hs-konec8", "font_statue", "swim out through that hole on the left.")
dialogStr("door dat gat links naarbuiten zouden zwemmen.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/pavement/dialogs_nl.lua <==

dialogId("dir-m-rada0", "font_small", "Stuff yourself with your advice.")
dialogStr("Hou je advies voor je!")


dialogId("dir-m-rada1", "font_small", "We know that very well.")
dialogStr("Dat weten wij ook wel!")


dialogId("dir-m-rada2", "font_small", "Get lost.")
dialogStr("Rot op!")


dialogId("dir-m-rada3", "font_small", "My patience is running out.")
dialogStr("Mijn geduld is op.")


dialogId("dir-m-rada4", "font_small", "Arrgh... I’ll smash it to pieces.")
dialogStr("Arrgh... Ik ga dat ding stuk slaan!")


dialogId("dir-v-rada0", "font_big", "Ignore it, let it talk.")
dialogStr("Negeer hem. Laat hem maar praten.")


dialogId("dir-v-rada1", "font_big", "Let us think.")
dialogStr("Eens denken...")


dialogId("dir-v-rada2", "font_big", "This was some advice, again.")
dialogStr("Dat was alweer advies.")


dialogId("dir-v-rada3", "font_big", "It's a shame I have no ears. I could plug them.")
dialogStr("Jammer dat we geen oren hebben. We zouden er iets in kunnen stoppen.")


dialogId("dir-v-rada4", "font_big", "I am fed up to my gills with its nonsense.")
dialogStr("Ik ben die onzin zo ongeloofelijk zat!")


dialogId("dir-hs-uvod0", "font_statue", "It would be easiest if you")
dialogStr("Het zou het handigst zijn als jullie")


dialogId("dir-hs-uvod1", "font_statue", "You would be better off if you")
dialogStr("Jullie zouden er een stuk beter voor staan als jullie")


dialogId("dir-hs-uvod2", "font_statue", "It would help you if you")
dialogStr("Het zou helpen als jullie")


dialogId("dir-hs-uvod3", "font_statue", "I have an idea. What if you")
dialogStr("Ik heb een idee. Wat nou als jullie")


dialogId("dir-hs-uvod4", "font_statue", "Sorry to interrupt, but what if you")
dialogStr("Pardon dat ik onderbreek. Maar wat als jullie nou")


dialogId("dir-hs-konec0", "font_statue", "demolish some wall.")
dialogStr("een paar muren omver zouden duwen.")


dialogId("dir-hs-konec1", "font_statue", "break off a few stones from the wall and plug the holes with them.")
dialogStr("een paar stenen van die muur daar af zouden breken en daar de kuilen mee zouden opvullen.")


dialogId("dir-hs-konec2", "font_statue", "plug those holes with something so that that hooked steel wouldn’t get stuck there.")
dialogStr("deze gaten zouden opvullen met iets, zodat dat hoekige stuk staal niet vast komt te zitten.")


dialogId("dir-hs-konec3", "font_statue", "smash that pillar by the exit.")
dialogStr("de pilaar bij de uitgang stuk zouden slaan.")


dialogId("dir-hs-konec4", "font_statue", "saw off some of that hooked steel.")
dialogStr("een stuk van dat hoekige stalen ding af zouden zagen.")


dialogId("dir-hs-konec5", "font_statue", "rearrange the objects so that you can swim out.")
dialogStr("de objecten zo zouden verplaatsen dat jullie weg kunnen zwemmen.")


dialogId("dir-hs-konec6", "font_statue", "solve it somehow and get to the next level.")
dialogStr("het op de een of andere manier zouden oplossen en het volgende veld zouden bereiken.")


dialogId("dir-hs-konec7", "font_statue", "start to think about it really hard.")
dialogStr("er heel erg hard over na zouden denken.")


dialogId("dir-hs-konec8", "font_statue", "swim out through that hole on the left.")
dialogStr("door dat gat links naarbuiten zouden zwemmen.")
